@@ -83,13 +83,14 @@ async def parse_link(url, credential: Credential = Credential()):
             sobj[0].credential = credential
             return sobj
 
-        
         black_room = parse_black_room(url)
         if not black_room == -1:
             obj = (black_room, ResourceType.BLACK_ROOM)
             return obj
 
         url = await get_real_url(url)
+        url = url.scheme + "://" + url.host + url.path
+        
 
         # 特殊处理，因为后面会过滤参数，这两项需要参数完成
         channel = parse_season_series(url)
@@ -155,7 +156,6 @@ async def parse_link(url, credential: Credential = Credential()):
             obj[0].credential = credential
             return obj
     except Exception as e:
-        raise e
         return -1
 
 
@@ -500,7 +500,7 @@ def parse_dynamic(url):
 def parse_black_room(url: str):
     if url.lstrip("https:") == url:
         url = "https:" + url
-    if url[:39] == 'https://www.bilibili.com/blackroom/ban/':
+    if url[:39] == "https://www.bilibili.com/blackroom/ban/":
         last_part = url[39:].replace("/", "")
         if last_part == "":
             return -1
